﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;

namespace ThinkGeo.MapSuite.Core
{
    public class BlinkingAreaStyle : AreaStyle
    {

        private Collection<GeoBrush> candidates;

        public BlinkingAreaStyle()
            : this(new GeoSolidBrush())
        { }

        public BlinkingAreaStyle(GeoSolidBrush fillSolidBrush)
            : this(new GeoPen(), fillSolidBrush, PenBrushDrawingOrder.BrushFirst)
        {
        }

        public BlinkingAreaStyle(GeoPen outlinePen)
            : this(outlinePen, new GeoSolidBrush(), PenBrushDrawingOrder.BrushFirst)
        {
        }

        public BlinkingAreaStyle(GeoPen outlinePen, GeoSolidBrush fillSolidBrush)
            : this(outlinePen, fillSolidBrush, PenBrushDrawingOrder.BrushFirst)
        {
        }

        public BlinkingAreaStyle(GeoPen outlinePen, GeoSolidBrush fillSolidBrush, PenBrushDrawingOrder penBrushDrawingOrder)
            : base(outlinePen, fillSolidBrush, penBrushDrawingOrder)
        {
            candidates = new Collection<GeoBrush>();
        }

        protected override void DrawCore(IEnumerable<Feature> features, GeoCanvas canvas, System.Collections.ObjectModel.Collection<SimpleCandidate> labelsInThisLayer, System.Collections.ObjectModel.Collection<SimpleCandidate> labelsInAllLayers)
        {
            foreach (var feature in features)
            {
                WellKnownType wkt = feature.GetWellKnownType();
                if (wkt != WellKnownType.Polygon && wkt != WellKnownType.Multipolygon && wkt != WellKnownType.GeometryCollection)
                {
                    continue;
                }

                canvas.DrawArea(feature, OutlinePen, GetFillBrush(), DrawingLevel);
            }
        }

        public Collection<GeoBrush> FillBrushes
        {
            get { return candidates; }
        }

        private GeoBrush GetFillBrush()
        {
            Random random = new Random();
            int index = random.Next(candidates.Count);

            return candidates[index];
        }
    }
}
